#!/usr/bin/env gosh

;; Copyright (c) Iwata <iwata@quasiquote.org>
;;
;; Permission is hereby granted, free of charge, to any person obtaining
;; a copy of this software and associated documentation files (the
;; "Software"), to deal in the Software without restriction, including
;; without limitation the rights to use, copy, modify, merge, publish,
;; distribute, sublicense, and/or sell copies of the Software, and to
;; permit persons to whom the Software is furnished to do so, subject to
;; the following conditions:
;;
;; The above copyright notice and this permission notice shall be included
;; in all copies or substantial portions of the Software.
;;
;; THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
;; EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
;; MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
;; IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
;; CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
;; TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
;; SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

;(add-load-path ".")

(use text.mijinko)

;; set your favorite database
(use dbm.gdbm)
(set! mijinko-dbtype <gdbm>)

;; getopt
(use srfi-37)

(define verbose-mode #f)

(define options
  (list (option '(#\l "learn") #f #f
                (lambda (option name arg learn quiet verbose db-name)
                  (values #t quiet verbose db-name)))
        (option '(#\q "quiet") #f #f
                (lambda (option name arg learn quiet verbose db-name)
                  (values learn #t verbose db-name)))
        (option '(#\v "verbose") #f #f
                (lambda (option name arg learn quiet verbose db-name)
                  (values learn quiet #t db-name)))))

(define (usage)
  (format (current-error-port)
          "Usage: ~a -[clqv] filename\n" *program-name*)
  (exit 2))

(define (main args)
  (receive (learn quiet verbose db-name)
      (args-fold (cdr args)
                 options
                 (lambda (option name arg . seeds)         ; unrecognized
                   (usage)
                   (exit 1))
                 (lambda (operand learn quiet verbose db-name) ; operand
                   (values learn quiet verbose operand))
                 #f     ; default value of learn
                 #f     ; default value of quiet
                 #f     ; default value of verbose
                 "mijinko.db"    ; initial value of input db-name
                 )
    (if verbose
        (set! verbose-mode #t))
    ;; main
    (mijinko-main learn quiet verbose db-name))
  (exit 1))
